<?php

namespace Drupal\symfony_debug\EventSubscriber;

use Symfony\Component\Debug\Debug;
use Symfony\Component\Debug\Exception\FlattenException;
use Symfony\Component\Debug\ExceptionHandler;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Event\GetResponseForExceptionEvent;
use Symfony\Component\HttpKernel\KernelEvents;

class KernelEventSubscriber implements EventSubscriberInterface {


  /**
   * @param \Symfony\Component\HttpKernel\Event\GetResponseForExceptionEvent $event
   *
   * @throws \Exception
   */
  public function onException(GetResponseForExceptionEvent $event) {
    $exception = $event->getException();
    if (!$exception instanceof FlattenException) {
      $exception = FlattenException::create($exception);
    }

    $handler = new ExceptionHandler();

    // Return a response before the default exception handler can do it.
    $event->setResponse(
      new Response($handler->getHtml($exception))
    );
  }

  /**
   *
   */
  public function onRequest() {
    // This needs to be called as early as possible in order to catch errors.
    Debug::enable();
  }

  /**
   * @return array
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::EXCEPTION => 'onException',
      KernelEvents::REQUEST => 'onRequest',
    ];
  }

}
